@@ -4,12 +4,14 @@
 {
     'name': 'Company',
     'name_bg_BG': 'Фирма',
+    'name_ca_ES': 'Empresa',
     'name_de_DE': 'Unternehmen',
+    'name_es_AR': 'Empresa',
     'name_es_CO': 'Compañía',
     'name_es_ES': 'Empresa',
     'name_fr_FR': 'Société',
     'name_nl_NL': 'Bedrijf',
-    'version': '2.2.2',
+    'version': '2.4.1',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -26,6 +28,13 @@ Make the scheduler run on each companies.
  - Задаване на нов анализатор на справки с фирмен горен колонтитул
  - Добавяне на шаблон на писмо за партньор
  - Възможност планировщика да работи на всяка фирма
+''',
+    'description_ca_ES': '''- Defineix empresa i empleats.
+- Afegeix l'empresa principal i predeterminada a les preferències dels usuaris.
+- Afegeix l'empresa a les propietats.
+- Defineix un nou analitzador pels informes amb l'encapçalament de l'empresa.
+- Afegeix una plantilla de carta a tercers.
+- Fa que el planificador de tasques s'executi per empresa.
 ''',
     'description_de_DE': ''' - Ermöglicht die Eingabe von Umternehmen und Mitarbeitern.
  - Fügt Haupt- und aktuelles Unternehmen zu den Benutzereinstellungen hinzu.
@@ -33,6 +42,13 @@ Make the scheduler run on each companies.
  - Ermöglicht die Definition eines neuen Berichtsanalysierers mit Unternehmen im Berichtskopf.
  - Fügt den Kontakten die Berichtsvorlage für Briefe hinzu.
  - Initialisiert die Aufgaben des Zeitplaners für jedes Unternehmen.
+''',
+    'description_es_AR': '''Define empresa y empleados.
+ - Añade la empresa principal y predeterminada en las preferencias de los usuarios.
+ - Añade empresa a las propiedades.
+ - Define un nuevo analizador de informe para los informes con el encabezado de la empresa.
+ - Añade una plantilla de carta en entidades.
+ - Hace que el programador de tareas se ejecute por empresa.
 ''',
     'description_es_CO': ''' - Define compañía y empleados.
  - Añade compañía principal y predeterminada de acuerdo a preferencia de usuarios.
@@ -43,10 +59,10 @@ Make the scheduler run on each companies.
 ''',
     'description_es_ES': '''Define empresa y empleados.
  - Añade la empresa principal y predeterminada en las preferencias de los usuarios.
- - Añade empresa a las propiedades.
- - Define un nuevo analizador de informe para los informes con el encabezado de la empresa.
- - Añade una plantilla de carta en terceros.
- - Hace que el programador de tareas se ejecute por empresa.
+ - Añade la empresa a las propiedades.
+ - Define un nuevo analizador para los informes con el encabezado de la empresa.
+ - Añade una plantilla de carta a terceros.
+ - Hace que el planificador de tareas se ejecute por empresa.
 ''',
     'description_fr_FR': '''Défini société et employé.
 Ajoute les sociétés principale et courante dans les préférences de l'utilisateur.
@@ -81,8 +97,10 @@ Lance les planificateurs sur chaque société.
     ],
     'translation': [
         'locale/bg_BG.po',
+        'locale/ca_ES.po',
         'locale/cs_CZ.po',
         'locale/de_DE.po',
+        'locale/es_AR.po',
         'locale/es_CO.po',
         'locale/es_ES.po',
         'locale/fr_FR.po',
